"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenerateReportUseCase = void 0;
const tslib_1 = require("tslib");
const tsyringe_1 = require("tsyringe");
const git_report_implementation_repository_1 = require("../../infrastructure/git-report.implementation.repository");
const git_report_list_1 = require("../../domain/git-report-list");
const os_1 = require("os");
const git_report_cli_printer_1 = require("../../infrastructure/cli/git-report.cli.printer");
let GenerateReportUseCase = class GenerateReportUseCase {
    constructor(repository, printer) {
        this.repository = repository;
        this.printer = printer;
    }
    async exec({ projectsPaths, weeks }) {
        if (projectsPaths.length === 0) {
            this.printer.info(os_1.EOL);
            return new git_report_list_1.GitReportList([]).mergeReports();
        }
        const { successfulReports, failedReports } = await this.generateReports(projectsPaths, weeks);
        this.printer.printFailedReports(failedReports);
        return new git_report_list_1.GitReportList(successfulReports).mergeReports();
    }
    async generateReports(projectsPaths, weeks) {
        const reports = await Promise.all(projectsPaths.map(async (projectPath) => {
            return this.repository.readGitReport({ projectPath, weeks, updateBeforeRead: false });
        }));
        return {
            successfulReports: reports.filter(report => !report.hasFailed()),
            failedReports: reports.filter(report => report.hasFailed()),
        };
    }
};
GenerateReportUseCase = tslib_1.__decorate([
    tsyringe_1.injectable(),
    tslib_1.__param(0, tsyringe_1.inject(git_report_implementation_repository_1.GitReportImplementationRepository)),
    tslib_1.__param(1, tsyringe_1.inject(git_report_cli_printer_1.GitReportCliPrinter)),
    tslib_1.__metadata("design:paramtypes", [Object, Object])
], GenerateReportUseCase);
exports.GenerateReportUseCase = GenerateReportUseCase;
//# sourceMappingURL=generate-report.case.js.map