"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitReportCli = void 0;
const command_1 = require("@oclif/command");
const tsyringe_1 = require("tsyringe");
const git_report_controller_1 = require("../git-report.controller");
const git_report_cli_printer_1 = require("./git-report.cli.printer");
class GitReportCli extends command_1.Command {
    async run() {
        const printer = tsyringe_1.container.resolve(git_report_cli_printer_1.GitReportCliPrinter);
        printer.printInit();
        const { argv: projects, flags: { anonymize, directory, forceUpdate, slackUrl, verbose, weeks, }, } = this.parse(GitReportCli);
        try {
            await tsyringe_1.container.resolve(git_report_controller_1.GitReportController).exec({
                anonymize,
                directory,
                forceUpdate,
                projects,
                slackUrl,
                verbose,
                weeks,
            });
        }
        catch (error) {
            printer.error(error.toString());
        }
    }
}
exports.GitReportCli = GitReportCli;
GitReportCli.strict = false;
GitReportCli.description = 'A command line tool for contribution reporting on git projects. The committers will be sorted based on contributions, taking into account commits, files changed, insertions and deletions.';
GitReportCli.flags = {
    anonymize: command_1.flags.boolean({
        char: 'a',
        description: 'Anonymize author names and emails.',
        default: false,
    }),
    directory: command_1.flags.string({
        char: 'd',
        description: 'Search for all git projects in a directory.',
        default: '',
    }),
    forceUpdate: command_1.flags.boolean({
        char: 'f',
        description: 'Update git projects before generating report.',
        default: false,
    }),
    help: command_1.flags.help({ char: 'h' }),
    slackUrl: command_1.flags.string({
        char: 's',
        description: 'Slack url for publishing report.',
        default: '',
    }),
    verbose: command_1.flags.boolean({
        description: 'Set multiline committer contribution info displaying total insertions and deletions. Otherwise the committer contribution info is display in one line with total commits and total files changed.',
        default: false,
    }),
    version: command_1.flags.version({ char: 'v' }),
    weeks: command_1.flags.integer({
        char: 'w',
        description: 'Number of weeks in the past to look for commits.',
        default: 4,
    }),
};
//# sourceMappingURL=git-report.cli.js.map