"use strict";
var GitReportController_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitReportController = void 0;
const tslib_1 = require("tslib");
const tsyringe_1 = require("tsyringe");
const path_1 = tslib_1.__importDefault(require("path"));
const generate_anonymize_report_for_projects_in_directory_case_1 = require("../application/cases/generate-anonymize-report-for-projects-in-directory.case");
const generate_anonymize_report_case_1 = require("../application/cases/generate-anonymize-report.case");
const generate_report_case_1 = require("../application/cases/generate-report.case");
const generate_report_for_projects_in_directory_case_1 = require("../application/cases/generate-report-for-projects-in-directory.case");
const notifier_1 = require("../../core/infrastructure/notifier");
const generate_updated_report_case_1 = require("../application/cases/generate-updated-report.case");
const os_1 = require("os");
const git_report_cli_printer_1 = require("./cli/git-report.cli.printer");
let GitReportController = GitReportController_1 = class GitReportController {
    constructor(notifier, printer) {
        this.notifier = notifier;
        this.printer = printer;
    }
    async exec(options) {
        const report = options.directory ?
            await this.executeReportForDirectory(options) :
            await this.executeReportForMultipleProjects(options);
        await this.printAndNotifyReport(report.toString({ verbose: options.verbose }), options);
    }
    async executeReportForDirectory({ directory, anonymize, weeks, forceUpdate, }) {
        this.printer.printStartFetchingDirectory(directory);
        return anonymize ?
            tsyringe_1.container.resolve(generate_anonymize_report_for_projects_in_directory_case_1.GenerateAnonymizeReportForProjectsInDirectoryUseCase).exec({
                directoryPath: directory,
                weeks,
                forceUpdate,
            }) :
            tsyringe_1.container.resolve(generate_report_for_projects_in_directory_case_1.GenerateReportForProjectsInDirectoryUseCase).exec({
                directoryPath: directory,
                weeks,
                forceUpdate,
            });
    }
    async executeReportForMultipleProjects({ projects, anonymize, weeks, forceUpdate }) {
        this.printer.printStartFetchingProjects(projects);
        const projectsAbsolutePaths = projects.map(project => path_1.default.resolve(project));
        if (anonymize) {
            return tsyringe_1.container.resolve(generate_anonymize_report_case_1.GenerateAnonymizeReportUseCase).exec({
                projectsPaths: projectsAbsolutePaths,
                weeks,
                forceUpdate,
            });
        }
        if (forceUpdate) {
            return tsyringe_1.container.resolve(generate_updated_report_case_1.GenerateUpdatedReportCase).exec({
                projectsPaths: projectsAbsolutePaths,
                weeks,
            });
        }
        return tsyringe_1.container.resolve(generate_report_case_1.GenerateReportUseCase).exec({
            projectsPaths: projectsAbsolutePaths,
            weeks,
        });
    }
    async printAndNotifyReport(report, { slackUrl, forceUpdate }) {
        if (forceUpdate) {
            this.printer.info(report);
            await this.notifyReport(slackUrl, report);
        }
        else {
            const reportWithWarning = GitReportController_1.concatReportWithoutUpdateWarning(report);
            this.printer.info(reportWithWarning);
            await this.notifyReport(slackUrl, reportWithWarning);
        }
    }
    async notifyReport(slackUrl, reportOutput) {
        if (slackUrl) {
            await this.notifier.publishOnSlack(slackUrl, reportOutput);
            this.printer.info('Report published on Slack.');
        }
    }
    static concatReportWithoutUpdateWarning(report) {
        return report.concat(`${os_1.EOL}${os_1.EOL}⚠️  The report could be outdated due to has been generated without updating git projects. Use --forceUpdate (-f) option for updating projects before generating the report.`);
    }
};
GitReportController = GitReportController_1 = tslib_1.__decorate([
    tsyringe_1.injectable(),
    tslib_1.__param(0, tsyringe_1.inject(notifier_1.Notifier)),
    tslib_1.__param(1, tsyringe_1.inject(git_report_cli_printer_1.GitReportCliPrinter)),
    tslib_1.__metadata("design:paramtypes", [notifier_1.Notifier, Object])
], GitReportController);
exports.GitReportController = GitReportController;
//# sourceMappingURL=git-report.controller.js.map